pub fn from_bytes<'a, T>(bytes: &'a [u8]) -> Result<T>where
T: Deserialize<'a>,Expand description
Deserialize a value of type T from a slice of bytes.
pub fn from_bytes<'a, T>(bytes: &'a [u8]) -> Result<T>where
T: Deserialize<'a>,Deserialize a value of type T from a slice of bytes.